ipecharts.option.seriesitems package
====================================

Submodules
----------

ipecharts.option.seriesitems.bar module
---------------------------------------

.. automodule:: ipecharts.option.seriesitems.bar
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.bar3d module
-----------------------------------------

.. automodule:: ipecharts.option.seriesitems.bar3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.boxplot module
-------------------------------------------

.. automodule:: ipecharts.option.seriesitems.boxplot
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.candlestick module
-----------------------------------------------

.. automodule:: ipecharts.option.seriesitems.candlestick
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.custom module
------------------------------------------

.. automodule:: ipecharts.option.seriesitems.custom
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.effectscatter module
-------------------------------------------------

.. automodule:: ipecharts.option.seriesitems.effectscatter
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.flowgl module
------------------------------------------

.. automodule:: ipecharts.option.seriesitems.flowgl
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.funnel module
------------------------------------------

.. automodule:: ipecharts.option.seriesitems.funnel
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.gauge module
-----------------------------------------

.. automodule:: ipecharts.option.seriesitems.gauge
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.graph module
-----------------------------------------

.. automodule:: ipecharts.option.seriesitems.graph
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.graphgl module
-------------------------------------------

.. automodule:: ipecharts.option.seriesitems.graphgl
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.heatmap module
-------------------------------------------

.. automodule:: ipecharts.option.seriesitems.heatmap
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.line module
----------------------------------------

.. automodule:: ipecharts.option.seriesitems.line
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.line3d module
------------------------------------------

.. automodule:: ipecharts.option.seriesitems.line3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.lines module
-----------------------------------------

.. automodule:: ipecharts.option.seriesitems.lines
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.lines3d module
-------------------------------------------

.. automodule:: ipecharts.option.seriesitems.lines3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.map module
---------------------------------------

.. automodule:: ipecharts.option.seriesitems.map
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.map3d module
-----------------------------------------

.. automodule:: ipecharts.option.seriesitems.map3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.pictorialbar module
------------------------------------------------

.. automodule:: ipecharts.option.seriesitems.pictorialbar
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.pie module
---------------------------------------

.. automodule:: ipecharts.option.seriesitems.pie
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.polygons3d module
----------------------------------------------

.. automodule:: ipecharts.option.seriesitems.polygons3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.sankey module
------------------------------------------

.. automodule:: ipecharts.option.seriesitems.sankey
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.scatter module
-------------------------------------------

.. automodule:: ipecharts.option.seriesitems.scatter
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.scatter3d module
---------------------------------------------

.. automodule:: ipecharts.option.seriesitems.scatter3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.scattergl module
---------------------------------------------

.. automodule:: ipecharts.option.seriesitems.scattergl
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.seriesparallel module
--------------------------------------------------

.. automodule:: ipecharts.option.seriesitems.seriesparallel
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.seriesradar module
-----------------------------------------------

.. automodule:: ipecharts.option.seriesitems.seriesradar
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.sunburst module
--------------------------------------------

.. automodule:: ipecharts.option.seriesitems.sunburst
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.surface module
-------------------------------------------

.. automodule:: ipecharts.option.seriesitems.surface
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.themeriver module
----------------------------------------------

.. automodule:: ipecharts.option.seriesitems.themeriver
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.tree module
----------------------------------------

.. automodule:: ipecharts.option.seriesitems.tree
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.seriesitems.treemap module
-------------------------------------------

.. automodule:: ipecharts.option.seriesitems.treemap
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ipecharts.option.seriesitems
   :members:
   :undoc-members:
   :show-inheritance:
